@@ -1,14 +1,15 @@
 #
-#  Copyright © 2021 Ingram Micro Inc. All rights reserved.
+#  Copyright © 2022 Ingram Micro Inc. All rights reserved.
 #
 
 from dj_rql.drf._utils import get_query
-from dj_rql.exceptions import RQLFilterParsingError
-from dj_rql.parser import RQLParser
 from dj_rql.transformer import RQLLimitOffsetTransformer
 
 from lark.exceptions import LarkError
 
+from py_rql.exceptions import RQLFilterParsingError
+from py_rql.parser import RQLParser
+
 from rest_framework.pagination import LimitOffsetPagination, _positive_int
 from rest_framework.response import Response
 
@@ -41,12 +42,28 @@ class RQLLimitOffsetPagination(LimitOffsetPagination):
                     'error': 'Limit and offset are set incorrectly.',
                 })
 
-        if self.get_limit() == 0:
+        self.limit = self.get_limit(request)
+        if self.limit == 0:
             self.count = self.get_count(queryset)
             self.offset = 0
             return []
 
-        return super(RQLLimitOffsetPagination, self).paginate_queryset(queryset, request, view)
+        elif self.limit is None:
+            return None
+
+        self.count = self.get_count(queryset)
+        self.offset = self.get_offset(request)
+        self.request = request
+        if self.count > self.limit and self.template is not None:
+            self.display_page_controls = True
+
+        if self.count == 0 or self.offset > self.count:
+            return []
+
+        if self.limit + self.offset > self.count:
+            self.limit = self.count - self.offset
+
+        return list(queryset[self.offset:self.offset + self.limit])
 
     def get_limit(self, *args):
         if self._rql_limit is not None:
